@@ -28,7 +28,7 @@ def table(query_text: str = '') -> str:
     if not DB.get('handle', None):
         DB['handle'] = api.login()
 
-    return api.markdown_table(DB['handle'], query_text)
+    print(api.markdown_table(DB['handle'], query_text))
 
 
 def init() -> None:
